@@ -25,6 +25,7 @@
 
 typedef struct {
     MD_HANDLE md;      /* catch all */
+    MD_HANDLE md2;     /* if we want to calculate an alternate hash */
     size_t maxbuf_size;
 } md_filter_context_t;
 
@@ -34,6 +35,9 @@ typedef struct {
     int only_keyblocks;     /* skip all headers but ".... key block" */
     const char *hdrlines;   /* write these headerlines */
 
+    /* these fileds must be initialized to zero */
+    int no_openpgp_data;    /* output flag: "No valid OpenPGP data found" */
+
     /* the following fields must be initialized to zero */
     int inp_checked;	    /* set if the input has been checked */
     int inp_bypass;	    /* set if the input is not armored */
@@ -43,6 +47,7 @@ typedef struct {
     int faked;		    /* we are faking a literal data packet */
     int truncated;	    /* number of truncated lines */
     int qp_detected;
+    int pgp2mode;
 
     byte *buffer;	    /* malloced buffer */
     unsigned buffer_size;   /* and size of this buffer */
@@ -54,6 +59,7 @@ typedef struct {
     u32 crc;
 
     int status; 	    /* an internal state flag */
+    int cancel;
     int any_data;	    /* any valid armored data seen */
     int pending_lf;	    /* used together with faked */
 } armor_filter_context_t;
@@ -76,6 +82,7 @@ typedef struct {
     u32 datalen;
     CIPHER_HANDLE cipher_hd;
     int header;
+    MD_HANDLE mdc_hash;
 } cipher_filter_context_t;
 
 
@@ -117,7 +124,7 @@ int cipher_filter( void *opaque, int control,
 int text_filter( void *opaque, int control,
 		 IOBUF chain, byte *buf, size_t *ret_len);
 int copy_clearsig_text( IOBUF out, IOBUF inp, MD_HANDLE md,
-			  int escape_dash, int escape_from );
+			  int escape_dash, int escape_from, int pgp2mode );
 
 
 
