@@ -61,9 +61,12 @@ static int  parse_key( IOBUF inp, int pkttype, unsigned long pktlen,
 				      byte *hdr, int hdrlen, PACKET *packet );
 static int  parse_user_id( IOBUF inp, int pkttype, unsigned long pktlen,
 							   PACKET *packet );
+static int  parse_photo_id( IOBUF inp, int pkttype, unsigned long pktlen,
+							   PACKET *packet );
 static int  parse_comment( IOBUF inp, int pkttype, unsigned long pktlen,
 							   PACKET *packet );
-static void parse_trust( IOBUF inp, int pkttype, unsigned long pktlen );
+static void parse_trust( IOBUF inp, int pkttype, unsigned long pktlen,
+							   PACKET *packet );
 static int  parse_plaintext( IOBUF inp, int pkttype, unsigned long pktlen,
 					       PACKET *packet, int new_ctb);
 static int  parse_compressed( IOBUF inp, int pkttype, unsigned long pktlen,
@@ -416,13 +419,17 @@ parse( IOBUF inp, PACKET *pkt, int reqtype, ulong *retpos,
       case PKT_USER_ID:
 	rc = parse_user_id(inp, pkttype, pktlen, pkt );
 	break;
+      case PKT_PHOTO_ID:
+	pkt->pkttype = pkttype = PKT_USER_ID;  /* must fix it */
+	rc = parse_photo_id(inp, pkttype, pktlen, pkt);
+	break;
       case PKT_OLD_COMMENT:
       case PKT_COMMENT:
 	rc = parse_comment(inp, pkttype, pktlen, pkt);
 	break;
       case PKT_RING_TRUST:
-	parse_trust(inp, pkttype, pktlen);
-	rc = G10ERR_UNKNOWN_PACKET;
+	parse_trust(inp, pkttype, pktlen, pkt);
+	rc = 0;
 	break;
       case PKT_PLAINTEXT:
 	rc = parse_plaintext(inp, pkttype, pktlen, pkt, new_ctb );
@@ -736,7 +743,14 @@ dump_sig_subpkt( int hashed, int type, int critical,
 	    printf(" %d", buffer[i] );
 	break;
       case SIGSUBPKT_REV_KEY:
-	p = "revocation key";
+	fputs("revocation key: ", stdout );
+	if( length < 22 )
+	    p = "[too short]";
+	else {
+	    printf("c=%02x a=%d f=", buffer[0], buffer[1] );
+	    for( i=2; i < length; i++ )
+		printf("%02X", buffer[i] );
+	}
 	break;
       case SIGSUBPKT_ISSUER:
 	if( length >= 8 )
@@ -785,7 +799,7 @@ dump_sig_subpkt( int hashed, int type, int critical,
 	p = "preferred key server";
 	break;
       case SIGSUBPKT_PRIMARY_UID:
-	p = "primary user id";
+	p = "primary user ID";
 	break;
       case SIGSUBPKT_POLICY:
 	fputs("policy: ", stdout );
@@ -795,10 +809,10 @@ dump_sig_subpkt( int hashed, int type, int critical,
 	p = "key flags";
 	break;
       case SIGSUBPKT_SIGNERS_UID:
-	p = "signer's user id";
+	p = "signer's user ID";
 	break;
       case SIGSUBPKT_PRIV_ADD_SIG:
-	p = "signs additional user id";
+	p = "signs additional user ID";
 	break;
       default: p = "?"; break;
     }
@@ -1467,6 +1481,8 @@ parse_user_id( IOBUF inp, int pkttype, unsigned long pktlen, PACKET *packet )
 
     packet->pkt.user_id = m_alloc(sizeof *packet->pkt.user_id  + pktlen);
     packet->pkt.user_id->len = pktlen;
+    packet->pkt.user_id->photo = NULL;
+    packet->pkt.user_id->photolen = 0;
     p = packet->pkt.user_id->name;
     for( ; pktlen; pktlen--, p++ )
 	*p = iobuf_get_noeof(inp);
@@ -1474,7 +1490,7 @@ parse_user_id( IOBUF inp, int pkttype, unsigned long pktlen, PACKET *packet )
 
     if( list_mode ) {
 	int n = packet->pkt.user_id->len;
-	printf(":user id packet: \"");
+	printf(":user ID packet: \"");
 	/* fixme: Hey why don't we replace this wioth print_string?? */
 	for(p=packet->pkt.user_id->name; n; p++, n-- ) {
 	    if( *p >= ' ' && *p <= 'z' )
@@ -1488,6 +1504,31 @@ parse_user_id( IOBUF inp, int pkttype, unsigned long pktlen, PACKET *packet )
 }
 
 
+/****************
+ * PGP generates a packet of type 17. We assume this is a photo ID and
+ * simply store it here as a comment packet.
+ */
+static int
+parse_photo_id( IOBUF inp, int pkttype, unsigned long pktlen, PACKET *packet )
+{
+    byte *p;
+
+    packet->pkt.user_id = m_alloc(sizeof *packet->pkt.user_id  + 30);
+    sprintf( packet->pkt.user_id->name, "[image of size %lu]", pktlen );
+    packet->pkt.user_id->len = strlen(packet->pkt.user_id->name);
+
+    packet->pkt.user_id->photo = m_alloc(sizeof *packet->pkt.user_id + pktlen);
+    packet->pkt.user_id->photolen = pktlen;
+    p = packet->pkt.user_id->photo;
+    for( ; pktlen; pktlen--, p++ )
+	*p = iobuf_get_noeof(inp);
+
+    if( list_mode ) {
+	printf(":photo_id packet: %s\n", packet->pkt.user_id->name );
+    }
+    return 0;
+}
+
 
 static int
 parse_comment( IOBUF inp, int pkttype, unsigned long pktlen, PACKET *packet )
@@ -1517,11 +1558,13 @@ parse_comment( IOBUF inp, int pkttype, unsigned long pktlen, PACKET *packet )
 
 
 static void
-parse_trust( IOBUF inp, int pkttype, unsigned long pktlen )
+parse_trust( IOBUF inp, int pkttype, unsigned long pktlen, PACKET *pkt )
 {
     int c;
 
     c = iobuf_get_noeof(inp);
+    pkt->pkt.ring_trust = m_alloc( sizeof *pkt->pkt.ring_trust );
+    pkt->pkt.ring_trust->trustval = c;
     if( list_mode )
 	printf(":trust packet: flag=%02x\n", c );
 }
