@@ -107,8 +107,10 @@ handle_plaintext( PKT_plaintext *pt, md_filter_context_t *mfx,
 		}
 		if( mfx->md )
 		    md_putc(mfx->md, c );
-		if( c == '\r' )
-		    continue; /* fixme: this hack might be too simple */
+	      #ifndef HAVE_DOSISH_SYSTEM
+		if( c == '\r' )  /* convert to native line ending */
+		    continue;	 /* fixme: this hack might be too simple */
+	      #endif
 		if( fp ) {
 		    if( putc( c, fp ) == EOF ) {
 			log_error("Error writing to `%s': %s\n",
@@ -152,8 +154,10 @@ handle_plaintext( PKT_plaintext *pt, md_filter_context_t *mfx,
 	    while( (c = iobuf_get(pt->buf)) != -1 ) {
 		if( mfx->md )
 		    md_putc(mfx->md, c );
+	      #ifndef HAVE_DOSISH_SYSTEM
 		if( convert && c == '\r' )
 		    continue; /* fixme: this hack might be too simple */
+	      #endif
 		if( fp ) {
 		    if( putc( c, fp ) == EOF ) {
 			log_error("Error writing to `%s': %s\n",
@@ -169,10 +173,10 @@ handle_plaintext( PKT_plaintext *pt, md_filter_context_t *mfx,
 	    int eof;
 	    for( eof=0; !eof; ) {
 		/* Why do we check for len < 32768:
-		 * If we won we would practically read 2 EOFS but
+		 * If we won't, we would practically read 2 EOFs but
 		 * the first one has already popped the block_filter
 		 * off and therefore we don't catch the boundary.
-		 * Always assume EOF if iobuf_read returns less bytes
+		 * So, always assume EOF if iobuf_read returns less bytes
 		 * then requested */
 		int len = iobuf_read( pt->buf, buffer, 32768 );
 		if( len == -1 )
@@ -217,6 +221,8 @@ handle_plaintext( PKT_plaintext *pt, md_filter_context_t *mfx,
 	    if( !state ) {
 		if( c == '\r'  )
 		    state = 1;
+		else if( c == '\n'  )
+		    state = 2;
 		else
 		    md_putc(mfx->md, c );
 	    }
@@ -308,7 +314,7 @@ ask_for_detached_datafile( MD_HANDLE md, MD_HANDLE md2,
     fp = open_sigfile( inname ); /* open default file */
     if( !fp && !opt.batch ) {
 	int any=0;
-	tty_printf("Detached signature.\n");
+	tty_printf(_("Detached signature.\n"));
 	do {
 	    m_free(answer);
 	    answer = cpr_get("detached_signature.filename",
