@@ -390,16 +390,30 @@ hash_uid_node( KBNODE unode, MD_HANDLE md, PKT_signature *sig )
     PKT_user_id *uid = unode->pkt->pkt.user_id;
 
     assert( unode->pkt->pkttype == PKT_USER_ID );
-    if( sig->version >=4 ) {
-	byte buf[5];
-	buf[0] = 0xb4; /* indicates a userid packet */
-	buf[1] = uid->len >> 24;  /* always use 4 length bytes */
-	buf[2] = uid->len >> 16;
-	buf[3] = uid->len >>  8;
-	buf[4] = uid->len;
-	md_write( md, buf, 5 );
+    if( uid->photo ) {
+	if( sig->version >=4 ) {
+	    byte buf[5];
+	    buf[0] = 0xd1;		   /* packet of type 17 */
+	    buf[1] = uid->photolen >> 24;  /* always use 4 length bytes */
+	    buf[2] = uid->photolen >> 16;
+	    buf[3] = uid->photolen >>  8;
+	    buf[4] = uid->photolen;
+	    md_write( md, buf, 5 );
+	}
+	md_write( md, uid->photo, uid->photolen );
+    }
+    else {
+	if( sig->version >=4 ) {
+	    byte buf[5];
+	    buf[0] = 0xb4;	      /* indicates a userid packet */
+	    buf[1] = uid->len >> 24;  /* always use 4 length bytes */
+	    buf[2] = uid->len >> 16;
+	    buf[3] = uid->len >>  8;
+	    buf[4] = uid->len;
+	    md_write( md, buf, 5 );
+	}
+	md_write( md, uid->name, uid->len );
     }
-    md_write( md, uid->name, uid->len );
 }
 
 /****************
@@ -433,9 +447,11 @@ check_key_signature2( KBNODE root, KBNODE node, int *is_selfsig, u32 *r_expire)
     sig = node->pkt->pkt.signature;
     algo = sig->digest_algo;
 
+  #if 0 /* I am not sure whether this is a good thing to do */
     if( sig->flags.checked )
 	log_debug("check_key_signature: already checked: %s\n",
 		      sig->flags.valid? "good":"bad" );
+  #endif
 
     if( (rc=check_digest_algo(algo)) )
 	return rc;
@@ -503,7 +519,7 @@ check_key_signature2( KBNODE root, KBNODE node, int *is_selfsig, u32 *r_expire)
 	    md_close(md);
 	}
 	else {
-	    log_error("no user id for key signature packet\n");
+	    log_error("no user ID for key signature packet\n");
 	    rc = G10ERR_SIG_CLASS;
 	}
     }
