@@ -39,6 +39,12 @@
 #include "i18n.h"
 
 
+#ifdef HAVE_DOSISH_SYSTEM
+  #define LF "\r\n"
+#else
+  #define LF "\n"
+#endif
+
 
 /****************
  * Create a notation.  It is assumed that the stings in STRLIST
@@ -582,7 +588,7 @@ clearsign_file( const char *fname, STRLIST locusr, const char *outfile )
     else if( (rc = open_outfile( fname, 1, &out )) )
 	goto leave;
 
-    iobuf_writestr(out, "-----BEGIN PGP SIGNED MESSAGE-----\n" );
+    iobuf_writestr(out, "-----BEGIN PGP SIGNED MESSAGE-----" LF );
 
     for( sk_rover = sk_list; sk_rover; sk_rover = sk_rover->next ) {
 	PKT_secret_key *sk = sk_rover->sk;
@@ -594,21 +600,28 @@ clearsign_file( const char *fname, STRLIST locusr, const char *outfile )
 	}
     }
 
-    if( old_style || only_md5 )
+    if( old_style && only_md5 )
 	iobuf_writestr(out, "\n" );
     else {
 	const char *s;
 	int any = 0;
+	byte hashs_seen[256];
 
+	memset( hashs_seen, 0, sizeof hashs_seen );
 	iobuf_writestr(out, "Hash: " );
 	for( sk_rover = sk_list; sk_rover; sk_rover = sk_rover->next ) {
 	    PKT_secret_key *sk = sk_rover->sk;
-	    s = digest_algo_to_string( hash_for(sk->pubkey_algo) );
-	    if( s ) {
-		if( any )
-		    iobuf_put(out, ',' );
-		iobuf_writestr(out, s );
-		any = 1;
+	    int i = hash_for(sk->pubkey_algo);
+
+	    if( !hashs_seen[ i & 0xff ] ) {
+		s = digest_algo_to_string( i );
+		if( s ) {
+		    hashs_seen[ i & 0xff ] = 1;
+		    if( any )
+			iobuf_put(out, ',' );
+		    iobuf_writestr(out, s );
+		    any = 1;
+		}
 	    }
 	}
 	assert(any);
