@@ -153,6 +153,7 @@ const char *strtimevalue( u32 stamp );
 const char *strtimestamp( u32 stamp ); /* GMT */
 const char *asctimestamp( u32 stamp ); /* localized */
 void print_string( FILE *fp, const byte *p, size_t n, int delim );
+void  print_utf8_string( FILE *fp, const byte *p, size_t n );
 char *make_printable_string( const byte *p, size_t n, int delim );
 int answer_is_yes( const char *s );
 int answer_is_yes_no_quit( const char *s );
@@ -175,7 +176,7 @@ int string_count_chr( const char *string, int c );
 int set_native_charset( const char *newset );
 const char* get_native_charset(void);
 char *native_to_utf8( const char *string );
-char *utf8_to_native( const char *string );
+char *utf8_to_native( const char *string, size_t length );
 int  check_utf8_string( const char *string );
 
 #ifndef HAVE_MEMICMP
@@ -187,6 +188,9 @@ char *stpcpy(char *a,const char *b);
 #ifndef HAVE_STRLWR
 char *strlwr(char *a);
 #endif
+#ifndef HAVE_STRCASECMP
+int strcasecmp( const char *, const char *b);
+#endif
 #ifndef HAVE_STRTOUL
   #define strtoul(a,b,c)  ((unsigned long)strtol((a),(b),(c)))
 #endif
@@ -197,6 +201,12 @@ char *strlwr(char *a);
   #define stricmp(a,b)	 strcasecmp( (a), (b) )
 #endif
 
+/*-- w32reg.c --*/
+#ifdef __MINGW32__
+char *read_w32_registry_string( const char *root,
+				const char *dir, const char *name );
+#endif
+
 /**** other missing stuff ****/
 #ifndef HAVE_ATEXIT  /* For SunOS */
   #define atexit(a)    (on_exit((a),0))
